Determines the hyperparameter of the THAMES for mixtures, as described in Metodiev et al. (2025).
chisq_find_limit(lps, d_par)the matrix param_test with one additional column
vector of unnormalized log-posterior values
number of (free) posterior parameters
Martin Metodiev, Nicholas J. Irons, Marie Perrot-Dockès, Pierre Latouche, Adrian E. Raftery. "Easily Computed Marginal Likelihoods for Multivariate Mixture Models Using the THAMES Estimator." arXiv preprint arXiv:2504.21812.