This function melts the simulations, presented as a n_simul x G x u array, into a matrix.
melt_sims_simple(sims, G)a matrix of dimension n_simul x (G(u+1)-1)
n_simul x G x (u+1) array of parameters sampled from the posterior, where n_simul is the number of simulations from the posterior, G is the number of components, u is the number of mixture component parameters (parameter u+1 is the mixture weight)
number of components